from __future__ import print_function
import re
import numpy as np
import os


def set_inlist(input_model_name, output_model_name, mdot, max_age, h1, he3, he4):
    # reads in the template inlist and writes out a new inlist with the 
    # parameters set appropriately
    
    inlist = open('inlist_flash_template','r')
    outlist = open('inlist_flash','w')

    for line in inlist.read().split('\n'):

        first = line.split()
        if len(first)>0:
            if first[0] != '!':

                if re.search('saved\_model\_name',line):
                    line = "\tsaved_model_name = '%s'  !set by driver.py" % input_model_name

                if re.search('save\_model\_filename',line):
                    line = "\tsave_model_filename = '%s'  !set by driver.py" % output_model_name

                if re.search('mass\_change ',line):
                    line = "\tmass_change = %g    !accretion rate (Msun/year) !set by driver.py" % mdot

                if re.search('max\_age',line):
                    line = "\tmax_age = %g   !set by driver.py" % max_age

                if re.search('accretion\_h1',line):
                    line = "\taccretion_h1 = %g   !set by driver.py" % h1

                if re.search('accretion\_he3',line):
                    line = "\taccretion_he3 = %g   !set by driver.py" % he3

                if re.search('accretion\_he4',line):
                    line = "\taccretion_he4 = %g   !set by driver.py" % he4

        print(line,file=outlist)

    outlist.close()
    inlist.close()


# white dwarf mass
mass = 0.8

# metallicity in the accreted material
Z = 0.02

# vector of accretion rates to try
# here use one value of accretion rate 
mdots = (3e-6,)
# or you can use many, e.g. 
# mdots = (1e-6, 1e-7, 1e-8, 1e-9, 1e-10)
# or
# mdots = 10.0**np.arange(20)*0.05 * (-4.0) -6.0


# start off with the steady state model at this mass
input_model_name = 'steady_burning_models/%.2fMsun_Tc_3e7_init.mod' % (mass,)

for mdot in mdots:
    output_model_name = 'mesa_nova_%.2fMsun_Tc3e7_mdot%g_Z%g.mod' % (mass, mdot, Z)
    suffix = '_M%.2f_mdot%g_Z%g' % (mass, mdot, Z)
    print(input_model_name,' --> ',output_model_name, ' with suffix:  ', suffix)

    if os.path.isfile(output_model_name):
        print('This model already exists, skip this step')
        input_model_name = output_model_name
    else:
        # set the H, He mass fractions according to the specified Z
        he3 = 3e-5
        a = 0.28 / 0.7   # Y/X for the H/He
        h1 = (1.0-Z-he3) / (1.0+a)
        he4 = a * (1.0-Z-he3) / (1.0+a)

        set_inlist(input_model_name, output_model_name, mdot, 1e-4/mdot, h1, he3, he4)
        os.system('\\rm -r LOGS; \\rm -r png; \\rm -r photos')

        print('------ MESA start ------')
        os.system('./rn')
        print('------ MESA done ------')

        if os.path.isfile(output_model_name):   # only make movie if the run made a model
            print('------ movie start ------')
            os.system("images_to_movie.sh 'png/grid1_*.png' movie" + suffix + ".mp4")
            print('------ movie done ------')

            os.system('cp LOGS/history.data history'+suffix+'.data')

            input_model_name = output_model_name
        else:
            continue
    